@@ -21,7 +21,6 @@
 
 #include "ktooltipwidget.h"
 
-#include <QApplication>
 #include <QPaintEvent>
 #include <QScreen>
 #include <QStylePainter>
@@ -30,7 +29,7 @@
 #include <QVBoxLayout>
 #include <QWindow>
 
-class KToolTipWidget::KToolTipWidgetPrivate
+class Q_DECL_HIDDEN KToolTipWidget::KToolTipWidgetPrivate
 {
 public:
     KToolTipWidgetPrivate(KToolTipWidget *parent)
@@ -90,6 +89,8 @@ void KToolTipWidget::KToolTipWidgetPrivate::show(const QPoint &pos, QWindow *tra
     }
 
     q->move(pos);
+    q->createWinId();
+    q->windowHandle()->setProperty("ENABLE_BLUR_BEHIND_HINT", true);
     q->windowHandle()->setTransientParent(transientParent);
     q->show();
 }
@@ -118,7 +119,7 @@ QPoint KToolTipWidget::KToolTipWidgetPrivate::centerBelow(const QRect &rect, QSc
     // - the content is fully visible
     // - the content is not drawn inside rect
 
-    const QSize size = content->sizeHint();
+    const QSize size = q->sizeHint();
     const int margin = q->style()->pixelMetric(QStyle::PM_ToolTipLabelFrameWidth);
     const QRect screenGeometry = screen->geometry();
 
@@ -137,17 +138,18 @@ QPoint KToolTipWidget::KToolTipWidgetPrivate::centerBelow(const QRect &rect, QSc
         if (x + size.width() >= screenGeometry.right()) {
             x = screenGeometry.right() - size.width() + 1;
         }
+        Q_ASSERT(x >= 0);
         if (hasRoomBelow) {
             y = rect.bottom() + margin;
         } else {
-            y = rect.top() - size.height() - margin;
+            y = rect.top() - size.height() - margin + 1;
         }
     } else {
         Q_ASSERT(hasRoomToLeft || hasRoomToRight);
         if (hasRoomToRight) {
             x = rect.right() + margin;
         } else {
-            x = rect.left() - size.width() - margin;
+            x = rect.left() - size.width() - margin + 1;
         }
         // Put the tooltip at the bottom of the screen. The x-coordinate has already
         // been adjusted, so that no overlapping with rect occurs.
@@ -161,9 +163,6 @@ KToolTipWidget::KToolTipWidget(QWidget *parent)
     : QWidget(parent), d(new KToolTipWidgetPrivate(this))
 {
     d->init();
-    // Tell the platform-specific window manager that we want blur behind.
-    createWinId();
-    windowHandle()->setProperty("ENABLE_BLUR_BEHIND_HINT", true);
 }
 
 KToolTipWidget::~KToolTipWidget()
@@ -180,6 +179,10 @@ void KToolTipWidget::showAt(const QPoint &pos, QWidget *content, QWindow *transi
 void KToolTipWidget::showBelow(const QRect &rect, QWidget *content, QWindow *transientParent)
 {
     d->addWidget(content);
+    const QSize marginSize{
+        2 * content->style()->pixelMetric(QStyle::PM_DefaultTopLevelMargin),
+        2 * content->style()->pixelMetric(QStyle::PM_DefaultTopLevelMargin)};
+    content->setMaximumSize(transientParent->screen()->geometry().size() - marginSize);
     d->show(d->centerBelow(rect, transientParent->screen()), transientParent);
 }
 
@@ -208,8 +211,12 @@ void KToolTipWidget::setHideDelay(int delay)
 
 void KToolTipWidget::enterEvent(QEvent *)
 {
-    // If the mouse hovers the tooltip, leave it visible.
-    d->hideTimer.stop();
+    // Ignore hide delay and leave tooltip visible.
+    if (hideDelay() > 0) {
+        d->hideTimer.stop();
+    } else {
+        hide();
+    }
 }
 
 void KToolTipWidget::hideEvent(QHideEvent *)
